# Web Core

[![Unit tests](https://github.com/sweetrpg/web-core/actions/workflows/python-ci.yml/badge.svg)](https://github.com/sweetrpg/web-core/actions/workflows/python-ci.yml)
[![Coverage](https://github.com/sweetrpg/web-core/blob/develop/coverage.svg)](https://github.com/sweetrpg/web-core)
[![PyPI version](https://badgen.net/pypi/v/sweetrpg-web-core)](https://pypi.org/project/sweetrpg-web-core)
[![License](https://img.shields.io/github/license/sweetrpg/web-core.svg)](https://img.shields.io/github/license/sweetrpg/web-core.svg)
[![Issues](https://img.shields.io/github/issues/sweetrpg/web-core.svg)](https://img.shields.io/github/issues/sweetrpg/web-core.svg)
[![PRs](https://img.shields.io/github/issues-pr/sweetrpg/web-core.svg)](https://img.shields.io/github/issues-pr/sweetrpg/web-core.svg)
[![Dependabot](https://badgen.net/github/dependabot/sweetrpg/web-core)](https://badgen.net/github/dependabot/sweetrpg/web-core)

[![Python](https://img.shields.io/badge/Python-3776AB?style=for-the-badge&logo=python&logoColor=white)](https://img.shields.io/badge/Python-3776AB?style=for-the-badge&logo=python&logoColor=white)
[![Built with love](https://ForTheBadge.com/images/badges/built-with-love.svg)](https://ForTheBadge.com/images/badges/built-with-love.svg)

Put something useful here.

## Documentation

Documentation for this package can be found [here](https://sweetrpg.github.io/web-core).
